#!/config/sh                              # just and only for syntax highlighting
#********************************************************************************
# qware build environment - header file of the qube configure script            *
#                                                                               *
#  Author: Kai Peter, ©2020-present                                             *
# Version: 0.6.11                                                               *
# License: ISC                                                                  *
#                                                                               *
# Description: Standard commands and functions of the qube configure process.   *
#              Only developers should adapt it to their package requirements.   *
#********************************************************************************
declare -r QUBEDIR=$1       # required (defined in the 'configure' script itself)
#----- default functions (basic) ------------------------------------------------
# if the file 'configure.help' doesn't exists, print message and exit
help() { [ -f "$QUBEDIR/configure.help" ] && cat $QUBEDIR/configure.help || \
         echo "No help available - sorry."; }
# general configure error handling: print message given by "$1" and exit
error() { [ "$1" ] && [ -n "$1" ] && printf "\033[91m$1!\033[0m\n" ; exit 1; }

getSystype() {
  echo -n "Checking system ... "
  local OS=`uname -s | tr '[A-Z]' '[a-z]'`
  echo "detected $OS!"
  echo -n "Checking architecture ... "
  local ARCH=`uname -m`
  echo "$OS:$ARCH" > systype
  echo "build on $ARCH!"
}

mkShebang() {
  QUBE_SHEBANG=`which env` || exit 1   # an error shouldn't happen, but who knows
  echo "#!$QUBE_SHEBANG bash" > ac-warn.sh   # output was formerly 'warn-auto.sh'
  echo "# !!! WARNING: This file was auto-generated. Do NOT edit!" >> ac-warn.sh
  # Hint: To use a different interpreter than 'sh' you can do something like this
  #       in a Makefile recipe (just an example to get the idea):
  #
  #       cat ac-warn.sh | sed 's/ sh$/ perl/g' | ...

  return
}

mkNIL() {
  local DEV=`df | grep /dev$ | awk '{print $NF;}'`
  [ -c $DEV/null ] && NIL=$DEV/null && return || \
    error "Cannot find $DEV/null - aborting!"
}
#**** begin processing **********************************************************
case $2 in
  --help|-h) help; exit 100;;    # this is the only command line option right now
         -*) error "Invalid option '$2'";;
esac

make clean
mkNIL; echo "$NIL" > ac-devnull

# get variables from 'conf-build' and corresponding 'conf-*' files **************
source "$QUBEDIR/conf-build" || exit 1    # required, must be present in any case
[ -f conf-build  ] && source ./conf-build               # deprecated
[ -f conf-prefix ] && PREFIX=`head -1 conf-prefix`      # deprecated
[ -f conf-suffix ] && SUFFIX=`head -1 conf-suffix`      # deprecated
# there could be either the one or the other file (user or distribution specific)
[ -f conf-local  ] && source ./conf-local || \
[ -f conf-dist   ] && source ./conf-dist

# include (source) the files containing the qube standard functions ...
F="$QUBEDIR/get-layout"    ; [ -f "$F" ] && source "$F"
F="$QUBEDIR/get-externals" ; [ -f "$F" ] && source "$F"
F="$QUBEDIR/get-usrcreds"  ; [ -f "$F" ] && source "$F"
F="$QUBEDIR/mk-buildtools" ; [ -f "$F" ] && source "$F"
F="$QUBEDIR/set-sysdeps"   ; [ -f "$F" ] && source "$F"
unset F
# ... and execute the qube standard functions
[ ! "$SYSTYPE" ] && getSystype
[ `type -t getLayout` ]    && getLayout
[ `type -t chkExtRes` ]    && chkExtRes
[ `type -t getUsrCreds` ]  && getUsrCreds
[ `type -t mkBuildTools` ] && mkBuildTools
[ `type -t setSysDeps` ]   && setSysDeps
. "$QUBEDIR"/mk-autotpl || error "Missing file mk-autotpl!"

# The last step: create 'ac-warn.sh' always *************************************
# Usually 'ac-warn.sh is required in 99.9% of build cases anyway, otherwise could
# be used in the Makefile to check if the configure script was invoked already.
[ -f ac-warn.sh ] || mkShebang
[ -f "$QUBEDIR/package.inc" ] && source "$QUBEDIR/package.inc"

#exit $?
